{% load i18n %}
{{ store_context.toolbar.stats.HistoryPanel.time|escape }}

{{ store_context.toolbar.stats.HistoryPanel.request_method|escape }}

{{ store_context.toolbar.stats.HistoryPanel.request_url|truncatechars:100|escape }}

{% trans "Variable" %} | {% trans "Value" %}
--- | ---
{% for key, value in store_context.toolbar.stats.HistoryPanel.data.items %}
`{{ key|pprint }}` | `{{ value|pprint }}`
{% empty %}
No data
{% endfor %}

{{ store_context.form }}